แพ็คเกจนี้เป็นแพ็คเกจ python ที่โชว์ข้อมูลเกี่ยวกับลุงวิศวกร สอนคำนวณ
=====================================================================

PyPi: https://pypi.org/project/mynameisuncle/

สวัสดีจ้าาา นี่คือแพ็คเกจที่แสดงข้อมูลเกี่ยวกับลุงวิศวกร
ท่านสามารถดูลิ้งค์เฟสบุ๊ค ลิ้งค์ยูทูป ลิ้งค์เพจได้ แสดงภาพศิลปะ ascii

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install mynameisuncle

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from mynameisuncle import UncleEngineer

   uncle = UncleEngineer() # ประกาศชื่อคลาส
   uncle.show_name() # โชว์ชื่อ
   uncle.show_youtube() # โชว์ลิ้งค์ยูทูป
   uncle.show_page() # โชว์ลิ้งค์เพจ
   uncle.about() # เกี่ยวกับลุง
   uncle.show_art() # โชว์ภาพศิลปะ

พัฒนาโดย: ลุงวิศวกร สอนคำนวณ FB: https://www.facebook.com/UncleEngineer

YouTube: https://www.youtube.com/UncleEngineer
